@@ -272,7 +272,7 @@ def _parse_pt(sample, msk_prob, rnd_prob, same_prob, max_obs):
     '''
 
     input_dict = get_sample(sample)
-
+    input_dict_v2 = {}
     sequence = sample_lc(input_dict['input'], max_obs)
     
     pad_mask = tf.reduce_sum(sequence, 1)
@@ -522,3 +522,103 @@ def from_generator(len, n, batch_size):
     ds_counter = ds_counter.take(n).cache()
     ds_counter = ds_counter.batch(batch_size)
     return ds_counter
+
+
+
+def _parse_pt_v2(sample, msk_prob, rnd_prob, same_prob, max_obs):
+    '''
+    Pretraining formater
+    '''
+
+    input_dict = get_sample(sample)
+    input_dict_v2 = {}
+    sequence = sample_lc(input_dict['input'], max_obs)
+    
+    pad_mask = tf.reduce_sum(sequence, 1)
+    pad_mask = tf.math.divide_no_nan(pad_mask, pad_mask)
+    curr_max_obs = tf.reduce_sum(pad_mask, 0)
+    pad_mask = tf.expand_dims(pad_mask, 1)
+    
+    sequence, mean = standardize(sequence, return_mean=True)
+
+    seq_time = tf.slice(sequence, [0, 0], [max_obs, 1])
+    seq_magn = tf.slice(sequence, [0, 1], [max_obs, 1])
+    seq_errs = tf.slice(sequence, [0, 2], [max_obs, 1])
+
+
+    # Save the true values
+    orig_magn = seq_magn
+
+    # [MASK] values
+    mask_out = get_masked(seq_magn, msk_prob)
+
+    # [MASK] -> Same values
+    seq_magn, mask_in = set_random(seq_magn,
+                                   mask_out,
+                                   seq_magn,
+                                   same_prob,
+                                   name='set_same')
+
+    # [MASK] -> Random value
+    seq_magn, mask_in = set_random(seq_magn,
+                                   mask_in,
+                                   tf.random.shuffle(seq_magn),
+                                   rnd_prob,
+                                   name='set_random')
+
+    time_steps = tf.shape(seq_magn)[0]
+
+    mask_out = tf.reshape(mask_out, [max_obs, 1])
+    mask_out = tf.multiply(mask_out, pad_mask)
+    
+    mask_in = tf.reshape(mask_in, [max_obs, 1])
+    mask_in = tf.maximum(1.-pad_mask, mask_in)
+
+
+
+    # output_dict['output']   = orig_magn
+    input_dict_v2['input']    = seq_magn
+    input_dict_v2['times']    = seq_time
+    # input_dict['mask_out'] = mask_out
+    input_dict_v2['mask_in']  = mask_in
+    # input_dict['length']   = curr_max_obs
+    # input_dict['mean']     = mean
+    # input_dict['obserr']   = seq_errs
+
+    return input_dict_v2, input_dict['label']
+
+
+def pretraining_records_v2(source, batch_size, shuffle=False, max_obs=100,
+                        msk_frac=0.2, rnd_frac=0.1, same_frac=0.1):
+    """
+    Pretraining data loader.
+    This method build the ASTROMER input format.
+    ASTROMER format is based on the BERT masking strategy.
+
+    Args:
+        source (string): Record folder
+        batch_size (int): Batch size
+        no_shuffle (bool): Do not shuffle training and validation dataset
+        max_obs (int): Max. number of observation per serie
+        msk_frac (float): fraction of values to be predicted ([MASK])
+        rnd_frac (float): fraction of [MASKED] values to replace with random values
+        same_frac (float): fraction of [MASKED] values to replace with true values
+
+    Returns:
+        Tensorflow Dataset: Iterator withg preprocessed batches
+    """
+    fn = adjust_fn(_parse_pt_v2, msk_frac, rnd_frac, same_frac, max_obs)
+
+    rec_paths = [os.path.join(source, folder, x) for folder in os.listdir(source) \
+                 for x in os.listdir(os.path.join(source, folder))]
+
+    dataset = tf.data.TFRecordDataset(rec_paths)
+    if shuffle:
+        print('[INFO] Shuffling')
+        dataset = dataset.shuffle(10000)
+
+    dataset = dataset.map(fn)
+    dataset = dataset.cache()
+    dataset = dataset.padded_batch(batch_size)
+    dataset = dataset.prefetch(buffer_size=tf.data.AUTOTUNE)
+    return dataset
\ No newline at end of file
